==> qtjambi-scxml-6.3.4-sources.jar: io/qt/scxml/QScxmlError.java <==
package io.qt.scxml;


/**
 * <p>Describes the errors returned by the Qt SCXML state machine when parsing an SCXML file</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qscxmlerror.html">QScxmlError</a></p>
 */
public class QScxmlError extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlError.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError">QScxmlError::QScxmlError()</a></p>
     */
    public QScxmlError(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QScxmlError instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError-2">QScxmlError::QScxmlError(QScxmlError)</a></p>
     */
    public QScxmlError(io.qt.scxml.QScxmlError arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QScxmlError instance, io.qt.scxml.QScxmlError arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError-1">QScxmlError::QScxmlError(QString,int,int,QString)</a></p>
     */
    public QScxmlError(java.lang.String fileName, int line, int column, java.lang.String description){
        super((QPrivateConstructor)null);
        initialize_native(this, fileName, line, column, description);
    }
    
    private native static void initialize_native(QScxmlError instance, java.lang.String fileName, int line, int column, java.lang.String description);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#column">QScxmlError::column()const</a></p>
     */
    @io.qt.QtPropertyReader(name="column")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int column(){
        return column_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int column_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#description">QScxmlError::description()const</a></p>
     */
    @io.qt.QtPropertyReader(name="description")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String description(){
        return description_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String description_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#fileName">QScxmlError::fileName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="fileName")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String fileName(){
        return fileName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String fileName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#isValid">QScxmlError::isValid()const</a></p>
     */
    @io.qt.QtPropertyReader(name="valid")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#line">QScxmlError::line()const</a></p>
     */
    @io.qt.QtPropertyReader(name="line")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int line(){
        return line_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int line_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#toString">QScxmlError::toString()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String toString(){
        return toString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String toString_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlError(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QScxmlError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QScxmlError clone_native(long __this_nativeId);
}

==> qtjambi-scxml-6.4.3-sources.jar: io/qt/scxml/QScxmlError.java <==
package io.qt.scxml;


/**
 * <p>Describes the errors returned by the Qt SCXML state machine when parsing an SCXML file</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qscxmlerror.html">QScxmlError</a></p>
 */
public class QScxmlError extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlError.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError">QScxmlError::QScxmlError()</a></p>
     */
    public QScxmlError(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QScxmlError instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError-2">QScxmlError::QScxmlError(QScxmlError)</a></p>
     */
    public QScxmlError(io.qt.scxml.QScxmlError arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QScxmlError instance, io.qt.scxml.QScxmlError arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#QScxmlError-1">QScxmlError::QScxmlError(QString,int,int,QString)</a></p>
     */
    public QScxmlError(java.lang.String fileName, int line, int column, java.lang.String description){
        super((QPrivateConstructor)null);
        initialize_native(this, fileName, line, column, description);
    }
    
    private native static void initialize_native(QScxmlError instance, java.lang.String fileName, int line, int column, java.lang.String description);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#column">QScxmlError::column()const</a></p>
     */
    @io.qt.QtPropertyReader(name="column")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int column(){
        return column_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int column_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#description">QScxmlError::description()const</a></p>
     */
    @io.qt.QtPropertyReader(name="description")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String description(){
        return description_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String description_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#fileName">QScxmlError::fileName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="fileName")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String fileName(){
        return fileName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String fileName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#isValid">QScxmlError::isValid()const</a></p>
     */
    @io.qt.QtPropertyReader(name="valid")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#line">QScxmlError::line()const</a></p>
     */
    @io.qt.QtPropertyReader(name="line")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int line(){
        return line_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int line_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlerror.html#toString">QScxmlError::toString()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String toString(){
        return toString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String toString_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QScxmlError(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QScxmlError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QScxmlError clone_native(long __this_nativeId);
}
